@@ -171,6 +171,7 @@ class Consul(object):
         self.health = Consul.Health(self)
         self.session = Consul.Session(self)
         self.acl = Consul.ACL(self)
+        self.status = Consul.Status(self)
 
     class Event(object):
         """
@@ -1565,3 +1566,27 @@ class Consul(object):
 
             return self.agent.http.put(
                 callback, '/v1/acl/destroy/%s' % acl_id, params=params)
+
+    class Status(object):
+        """
+        The Status endpoints are used to get information about the status
+         of the Consul cluster.
+        """
+        def __init__(self, agent):
+            self.agent = agent
+
+        def leader(self):
+            """
+            This endpoint is used to get the Raft leader for the datacenter
+            in which the agent is running.
+            """
+            return self.agent.http.get(
+                lambda x: json.loads(x.body), '/v1/status/leader')
+
+        def peers(self):
+            """
+            This endpoint retrieves the Raft peers for the datacenter in which
+            the the agent is running.
+            """
+            return self.agent.http.get(
+                lambda x: json.loads(x.body), '/v1/status/peers')
